@@ -2,8 +2,8 @@
 
 /// Emits a Write implementation for hashes.
 macro_rules! impl_write_for_hash {
-    ($name:ident) => {
-        impl ::std::io::Write for $name {
+    ($($name:tt)*) => {
+        impl ::std::io::Write for $($name)* {
             fn write(&mut self, buf: &[u8]) -> ::std::io::Result<usize> {
                 self.update(buf);
                 Ok(buf.len())
