@@ -30,7 +30,9 @@ pub mod random;
 pub mod ecc;
 
 pub mod curve25519;
+pub mod curve448;
 pub mod dsa;
 pub mod ecdh;
 pub mod ecdsa;
 pub mod ed25519;
+pub mod ed448;
